use strict;
use warnings;
package App::LWP::Online;

#ABSTRACT: Command line tool to check internet status.
our $VERSION = '0.0.6'; # VERSION
#

=pod

=encoding UTF-8

=head1 NAME

App::LWP::Online - Command line tool to check internet status.

=head1 VERSION

version 0.0.6

=head1 SYNOPSIS

	lwp-online # => online or offline

=head1 DESCRIPTION

Check internet status if online or offline.

=head1 AUTHOR

faraco <skelic3@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by faraco.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

__END__

1;
